package io.humanteq.hqm;

import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.modules.core.DeviceEventManagerModule;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;
import java.util.Iterator;

import io.humanteq.hq_core.HQSdk;
import io.humanteq.hq_core.interfaces.HQCallback;
import io.humanteq.hq_core.main.HQApi;
import io.humanteq.hq_core.models.SegmentData;
import io.humanteq.hq_core.models.UserGroup;

import android.app.Application;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.util.Log;

public class RNHqmModule extends ReactContextBaseJavaModule {

  private final ReactApplicationContext reactContext;
  private Application application;

  public RNHqmModule(ReactApplicationContext reactContext) {
    super(reactContext);
    this.reactContext = reactContext;
    this.application = (Application) reactContext.getApplicationContext();
  }

  @Override
  public String getName() {
    return "RNHqm";
  }

  @ReactMethod
  public void initSdk(final ReadableMap options, final Callback successCallback, final Callback errorCallback) {
    try {
      final String sdkKey = options.getString("sdkKey");
      final boolean isDebug = options.getBoolean("isDebug");

      HQSdk.init(this.application, sdkKey, isDebug, new HQCallback<Void>() {
        @Override
        public void onSuccess(Void data) {
          successCallback.invoke("HQM ok");
        }

        @Override
        public void onError(Throwable ex) {
          errorCallback.invoke(ex.getMessage());
        }
      });
    } catch (Exception e) {
      errorCallback.invoke(e.getMessage());
    }
  }

  @ReactMethod
  public void log(String key, String value) {
    HQSdk.logEvent(key, value);
  }

  @ReactMethod
  public void start() {
    HQSdk.start(this.application);
  }

  @ReactMethod
  public void trackSegments(boolean enable, String tracker) {
    switch (tracker) {
      case "AppsFlyer":
        HQSdk.trackSegments(enable, HQApi.EventTracker.AppsFlyer);
        break;
      case "Firebase":
        HQSdk.trackSegments(enable, HQApi.EventTracker.Firebase);
        break;
    }
  }
}